@@ -12,23 +12,23 @@
 //! use rad::RadError;
 //! use rad::Processor;
 //! use rad::MacroType;
-//! use rad::auth::AuthType;
-//! use std::path::{Path, PathBuf};
+//! use rad::AuthType;
+//! use std::path::Path;
 //! 
 //! // Builder
-//! let processor = Processor::new()
-//!     .purge(true)
-//!     .greedy(true)
-//!     .silent(true)
-//!     .strict(true)
-//!     .custom_rules(Some(vec![Pathbuf::from("rule.r4f")])) // Read from frozen rule files
-//!     .write_to_file(Some(PathBuf::from("out.txt")))?      // default is stdout
-//!     .error_to_file(Some(PathBuf::from("err.txt")))?      // default is stderr
+//! let mut processor = Processor::new()
+//!     .purge(true)                                         // Purge undefined macro
+//!     .greedy(true)                                        // Makes all macro greedy
+//!     .silent(true)                                        // Silents all errors and warnings
+//!     .strict(true)                                        // Enable strict mode, panicks on any error
+//!     .custom_rules(Some(vec![Path::new("rule.r4f")]))?    // Read from frozen rule files
+//!     .write_to_file(Some(Path::new("out.txt")))?          // default is stdout
+//!     .error_to_file(Some(Path::new("err.txt")))?          // default is stderr
 //!     .unix_new_line(true)                                 // use unix new line for formatting
-//!     .discard(true)?                                      // discard all output
+//!     .discard(true)                                       // discard all output
 //!     // Permission
-//!     .allow(Some(vec![AuthType::ENV]))
-//!     .allow_with_warning(Some(vec![AuthType::CMD]))
+//!     .allow(Some(vec![AuthType::ENV]))                    // Grant permission of authtypes
+//!     .allow_with_warning(Some(vec![AuthType::CMD]))       // Grant permission of authypes with warning enabled
 //!     // Debugging options
 //!     .debug(true)                                         // Turn on debug mode
 //!     .log(true)                                           // Use logging to terminal
@@ -46,11 +46,11 @@
 //! // Add custom rules(in order of "name, args, body") 
 //! processor.add_custom_rules(vec![("test","a_src a_link","$a_src() -> $a_link()")]);
 //! 
-//! processor.from_string(r#"$define(test=Test)"#);
-//! processor.from_stdin();
-//! processor.from_file(Path::new("from.txt"));
-//! processor.freeze_to_file(Path::new("out.r4f")); // Create frozen file
-//! processor.print_result();                       // Print out warning and errors count
+//! processor.from_string(r#"$define(test=Test)"#)?;
+//! processor.from_stdin()?;
+//! processor.from_file(Path::new("from.txt"))?;
+//! processor.freeze_to_file(Path::new("out.r4f"))?; // Create frozen file
+//! processor.print_result()?;                       // Print out warning and errors count
 //! ```
 
 use auth::{AuthType, AuthFlags, AuthState};
@@ -140,12 +140,15 @@ impl Processor {
     /// Only basic macro usage should be given as an argument.
     fn new_processor(use_basic: bool) -> Self {
         let temp_path= std::env::temp_dir().join("rad.txt");
-        let temp_target = (temp_path.to_owned(),OpenOptions::new()
+        let temp_target = (
+            temp_path.to_owned(),
+            OpenOptions::new()
             .create(true)
             .write(true)
             .truncate(true)
             .open(&temp_path)
-            .unwrap());
+            .unwrap()
+        );
 
         let mut logger = Logger::new();
         logger.set_write_options(Some(WriteOption::Stdout));
@@ -187,7 +190,7 @@ impl Processor {
     }
 
     /// Set write option to yield output to the file
-    pub fn write_to_file(&mut self, target_file: Option<PathBuf>) -> Result<&mut Self, RadError> {
+    pub fn write_to_file(&mut self, target_file: Option<impl AsRef<Path>>) -> Result<&mut Self, RadError> {
         if let Some(target_file) = target_file {
             let target_file = OpenOptions::new()
                 .create(true)
@@ -201,7 +204,7 @@ impl Processor {
     }
 
     /// Yield error to the file
-    pub fn error_to_file(&mut self, target_file: Option<PathBuf>) -> Result<&mut Self, RadError> {
+    pub fn error_to_file(&mut self, target_file: Option<impl AsRef<Path>>) -> Result<&mut Self, RadError> {
         if let Some(target_file) = target_file {
             let target_file = OpenOptions::new()
                 .create(true)
@@ -260,37 +263,37 @@ impl Processor {
 
     /// Add debug options
     #[cfg(feature = "debug")]
-    pub fn debug(&mut self, debug: bool) -> Result<&mut Self, RadError> {
+    pub fn debug(&mut self, debug: bool) -> &mut Self {
         if debug {
             self.debug = true;
         }
-        Ok(self)
+        self
     }
 
     /// Add debug log options
     #[cfg(feature = "debug")]
-    pub fn log(&mut self, log: bool) -> Result<&mut Self, RadError> {
+    pub fn log(&mut self, log: bool) -> &mut Self {
         if log {
             self.debug_log = true;
         }
-        Ok(self)
+        self
     }
 
     /// Add debug interactive options
     #[cfg(feature = "debug")]
-    pub fn interactive(&mut self, interactive: bool) -> Result<&mut Self, RadError> {
+    pub fn interactive(&mut self, interactive: bool) -> &mut Self {
         if interactive {
             self.logger.set_debug_interactive();
         }
-        Ok(self)
+        self
     }
 
     /// Add custom rules
-    pub fn custom_rules(&mut self, paths: Option<Vec<PathBuf>>) -> Result<&mut Self, RadError> {
+    pub fn custom_rules(&mut self, paths: Option<Vec<impl AsRef<Path>>>) -> Result<&mut Self, RadError> {
         if let Some(paths) = paths {
             let mut rule_file = RuleFile::new(None);
             for p in paths.iter() {
-                rule_file.melt(p)?;
+                rule_file.melt(p.as_ref())?;
             }
             self.map.custom.extend(rule_file.rules);
         }
@@ -299,31 +302,31 @@ impl Processor {
     }
 
     /// Open authority of processor
-    pub fn allow(&mut self, auth_types : Option<Vec<AuthType>>) -> Result<&mut Self, RadError> {
+    pub fn allow(&mut self, auth_types : Option<Vec<AuthType>>) -> &mut Self {
         if let Some(auth_types) = auth_types {
             for auth in auth_types {
                 self.auth_flags.set_state(&auth, AuthState::Open)
             }
         }
-        Ok(self)
+        self
     }
 
     /// Open authority of processor but yield warning
-    pub fn allow_with_warning(&mut self, auth_types : Option<Vec<AuthType>>) -> Result<&mut Self, RadError> {
+    pub fn allow_with_warning(&mut self, auth_types : Option<Vec<AuthType>>) -> &mut Self {
         if let Some(auth_types) = auth_types {
             for auth in auth_types {
                 self.auth_flags.set_state(&auth, AuthState::Warn)
             }
         }
-        Ok(self)
+        self
     }
 
     /// Discard output
-    pub fn discard(&mut self, discard: bool) -> Result<&mut Self, RadError> {
+    pub fn discard(&mut self, discard: bool) -> &mut Self {
         if discard {
             self.write_option = WriteOption::Discard;
         }
-        Ok(self)
+        self
     }
 
     /// Creates a unreferenced instance of processor
@@ -347,8 +350,8 @@ impl Processor {
     }
 
     /// Freeze to single file
-    pub fn freeze_to_file(&self, path: &Path) -> Result<(), RadError> {
-        RuleFile::new(Some(self.map.custom.clone())).freeze(path)?;
+    pub fn freeze_to_file(&self, path: impl AsRef<Path>) -> Result<(), RadError> {
+        RuleFile::new(Some(self.map.custom.clone())).freeze(path.as_ref())?;
         Ok(())
     }
 
@@ -405,10 +408,10 @@ impl Processor {
     }
 
     /// Process contents from a file
-    pub fn from_file(&mut self, path :&Path) -> Result<String, RadError> {
+    pub fn from_file(&mut self, path :impl AsRef<Path>) -> Result<String, RadError> {
 
         // Set file as name of given path
-        self.set_file(path.to_str().unwrap())?;
+        self.set_file(path.as_ref().to_str().unwrap())?;
 
         let file_stream = File::open(path)?;
         let mut reader = BufReader::new(file_stream);
@@ -1275,7 +1278,7 @@ impl Processor {
 
     /// Get temp file's path
     pub(crate) fn get_temp_path(&self) -> &Path {
-        &self.temp_target.0
+        self.temp_target.0.as_ref()
     }
 
     /// Get temp file's "file" struct
@@ -1316,7 +1319,7 @@ impl Processor {
     // This is not a backup but fresh set of file information
     /// Set(update) current processing file information
     fn set_file(&mut self, file: &str) -> Result<(), RadError> {
-        let path = &Path::new(file);
+        let path = Path::new(file);
         if !path.exists() {
             Err(RadError::InvalidCommandOption(format!("File, \"{}\" doesn't exist, therefore cannot be read by r4d.", path.display())))
         } else {
